@@ -5,6 +5,8 @@ def deprecated (msg = ""):
     def decorator (f):
         @wraps(f)
         def wrapper (*args, **kwargs):
+            nonlocal msg
+
             warnings.simplefilter ('default')
             warnings.warn (
                "{} will be deprecated{}".format (f.__name__, msg and (", " + msg) or ""),
@@ -12,7 +14,11 @@ def deprecated (msg = ""):
             )
             return f (*args, **kwargs)
         return wrapper
-    return decorator
+
+    if isinstance (msg, str):
+        return decorator
+    f, msg = msg, ''
+    return decorator (f)
 
 def override (f):
     @wraps (f)
