@@ -37,7 +37,7 @@ if __name__ == "__main__":
     token = os.environ.get ('TELEGRAM_TOKEN')
     if not token:
         raise SystemExit ('telegram token reqired')
-    chat_id = os.environ.get ('TELGRAM_CHAT_ID')
+    chat_id = os.environ.get ('TELEGRAM_CHAT_ID')
     commit_title = os.environ.get ("CI_COMMIT_TITLE", "")
     if commit_title.find ('--tg-silent') != -1:
         sys.exit ()
