@@ -2,7 +2,7 @@ import os
 import signal, psutil
 
 def thread (thread):
-    import ctypes    
+    import ctypes
     if not thread.isAlive():
         return
     exc = ctypes.py_object(SystemExit)
@@ -19,17 +19,22 @@ def process (p, sig = signal.SIGTERM):
     if isinstance (p, int):
         # resolve to process
         try:
-            p = psutil.Process (p)        
+            p = psutil.Process (p)
         except psutil.NoSuchProcess:
-            return    
+            return
     p.send_signal (sig)
 
 # utils -------------------------------------------
-def child_processes (parent_pid = os.getpid (), sig = signal.SIGTERM):    
+def child_processes (parent_pid = os.getpid (), sig = signal.SIGTERM):
     try:
         parent = psutil.Process (parent_pid)
     except psutil.NoSuchProcess:
         return
     children = parent.children (recursive = True)
     for process in children:
-        process.send_signal (sig)
\ No newline at end of file
+        process.send_signal (sig)
+    return parent.children (recursive = True)
+
+def child_processes_gracefully (parent_pid = os.getpid ()):
+    if child_processes (parent_pid) and os.name == 'posix':
+        child_processes (parent_pid, signal.SIGKILL)
